%--------------------------------------------------------------------------
% Plot EDPs from MPS exact sets, along with their median values, and compare with
% median/target values from benchmark EDPs (Longitudinal Direction)
%
% Summary: 
% post_process.mat files are loaded from the benchmark and MPS-exact sets
% directories and comparison plots are generated. Rough discrepancies
% and std devations are computed and displayed.
%
% Written by: E.Kalkan
% Modified by: N.Kwong (nealsimonkwong@berkeley.edu)
% Date modified: Nov 2010

%% ----------------------DEFINITIONS---------------------------------------
% n                     = number of records in benchmark set
% fpath_BM              = specifies location of workspace file for
%                         benchmark EDPs
% fpath_MPS             = specifies location of sets of records scaled by
%                         MPS-exact method
% fpath                 = file path to place saved figures 
% fname                 = name for figures to be saved
% target_medRDR         = median drift ratio among all benchmark records
% target_medCol_Rot     = median column plastic rotation among all
%                         benchmark records
% discrp                = matrix of discrepancies between drift ratio for
%                         ith GM in MPS exact and the target from benchmark
% discrp_Col_Rot        = matrix of discrepancies between column plastic
%                         rotation for ith GM in MPS exact and the target
%                         from benchmark
% ave_discrp1_RDR       = ratio of median drift ratio among MPS exact set
%                         and target from benchmark
% ave_discrp1_Col_Rot   = ratio of median column plastic rotation among MPS
%                         exact set and target from benchmark
% output                = collection of ratios of median ratios
% dispersion_RDR        = standard deviation of drift ratios in MPS exact
%                         set relative to benchmark
% dispersion_Col_Rot    = standard deviation of column plastic rotations in
%                         MPS exact set relative to benchmark
% output2               = collection of dispersions

%% User Input--------------------------------------------------------------
clear all; clc; close all;
n = input('Enter Number of Sets: ', 's');   
n = str2num(n);

fpath_BM = 'J:\MPS\Skew Bridge\NLRHA\Benchmark\Skew_Unscaled\post_process.mat';
fpath_MPS = 'J:\MPS\Skew Bridge\NLRHA\Sets_Exact\';
fpath = 'J:\MPS\Skew Bridge\Figures\';
fname = 'Fig_37_Bar_MPS_BM_Comp_Skw_Exact_Long';

%% Extract benchmark EDP values for comparison
load(fpath_BM);
target_medRDR = geomean(RDR_Long')*100;
target_medCol_Rot = geomean(PlasticRot_Long_Max');

%% Plot EDPs from all MPS Exact sets of records
figure(1); orient tall; clf; 
set(gcf,'position',[300 283 220*n 450]);
set(gca,'TickLength',[.0025 .0025]);

subplot1(2,n,'Gap',[0.015 0.015]);

for w = 1:n;
    titl = strcat('Set-',num2str(w));
    filename = strcat(fpath_MPS,'Set-',num2str(w),'\Skew_Unscaled\post_process.mat');
    load (filename);
    clear line;
    medRDR = geomean(RDR_Long')*100;
    medRDR = medRDR';
    medCol_Rot = geomean(PlasticRot_Long_Max');

    subplot1(w);
        X = [0 7]; Y = [medRDR medRDR];
        Y_target = [target_medRDR target_medRDR];
        bar(NodalDisp_Long_Max/h*100,'EdgeColor','k','FaceColor',[0.5 0.5 0.5],'Barwidth',0.5);
        plot(X, Y_target,'-k','LineWidth',2.0);
        plot(X, Y,'--r','LineWidth',2.0);
        axis([1 7 0 7]);
        %         set(gca,'Ytick',[0:7]);
        set(gca,'fontsize',9);axis square;
        set(gca,'xtick',[1:7]);
        %set(gca,'YTickLabel',{'0','','2','','4','','6'},'fontsize',9);
        text('pos',[3.6 7.3],'str',titl,'FontSize',[9],'FontWeight','bold');
        if w == 1;
            ylabel('Deck Drift Ratio (%)','FontSize',[10],'FontWeight','bold');
            % LEGEND: Use X and Y vectors as grid, then input values for
            % relative placement of items in legend
            X1 = [3.4 4.5];     % Vertical lines
            Y1 = [6.5 6.5];   Y2 = [6 6];   % Horizontal lines
            Y3 = [5.25 5.25];   Y4 = [4.75 4.75];

            space = 0.2;

            % Benchmark text and accompanying line
            text('pos',[X1(2)+space Y1(2)],'str','Benchmark','Color','k','FontSize',[9],'FontWeight','normal');
            line(X1,Y1,'Color','k','LineWidth',2.0);

            % MPS... text and underlying line
            text('pos',[X1(2)+space Y2(2)],'str','MPS-"Exact"','Color','k','FontSize',[9],'FontWeight','normal');
            X2 = [4.6 6.8];
            line(X2,Y2-0.25,'Color','k','LineWidth',1);

            % Median text and accompanying line
            text('pos',[X1(2)+space Y3(2)],'str','Median','Color','k','FontSize',[9],'FontWeight','normal');
            plot(X1,Y3,'--','Color','r','LineWidth',2.0);

            % Ith GM text and accompanying box
            rect_h = 0.5;
            text('pos',[X1(2)+space Y4(2)],'str','i^t^h GM','Color','k','FontSize',[9],'FontWeight','normal');
            rectangle('Position',[X1(1),[Y4(2)-(rect_h/2)],[X1(2)-X1(1)],rect_h],'FaceColor',[0.5 0.5 0.5],'LineWidth',0.5,'LineStyle','-');
        end
    
    subplot1(w+3);
        set(gca,'fontsize',9);axis square;
        Y = [medCol_Rot medCol_Rot];
        Y_target = [target_medCol_Rot target_medCol_Rot];
        bar(PlasticRot_Long_Max,'EdgeColor','k','FaceColor',[0.5 0.5 0.5],'Barwidth',0.5);
        plot(X, Y,'--r','LineWidth',2.0);
        plot(X, Y_target,'-k','LineWidth',2.0);

        axis([1 7 0 0.05]);
        set(gca,'xtick',[1:7]);
        if w == 1;
            ylabel('Column Plastic Rot. (rad)','FontSize',[10],'FontWeight','bold');
            %             set(gca,'Ytick',[0:0.0025:0.015]);
            %             set(gca,'YTickLabel',{'0','','0.005','','0.01','','0.015'},'fontsize',9);
        elseif w == 2;
            xlabel('Ground Motion','FontSize',[10],'FontWeight','bold');
        end
    % Max. discrepancy in each set
    for i = 1:7
        discrp(w,i) = RDR_Long(i)/target_medRDR*100;
        discrp_Col_Rot(w,i) = PlasticRot_Long_Max(i)/target_medCol_Rot;
    end
    ave_discrp1_RDR(w) = medRDR / target_medRDR*100;
    ave_discrp1_Col_Rot(w) = medCol_Rot / target_medCol_Rot*100;
end

% savefile(fpath,fname);

%% Compute and display ratios of median values and standard deviations 
% open discrp
ave_discrp2 = mean(discrp,2);

output = [ave_discrp1_RDR 
    ave_discrp1_Col_Rot];
output = output/100;
open output

dispersion_RDR = std(discrp,0,2);
dispersion_Col_Rot = std(discrp_Col_Rot,0,2);
output2 = [dispersion_RDR'
    dispersion_Col_Rot'];
open output2