% This file is used in calcSpectrum function
% Central Difference method
% Function to calculate displacement & velocity response histories
%
% Written by: N.Kwong
% Date Modified: 17 Oct 2010
%% ----------------------DEFINITIONS---------------------------------------
% flag = indicator for ground motion (1 = yes)
% wn   = natural circular frequency in rad/sec^2
% xi   = damping ratio
% u0   = initial displacement
% v0   = initial velocity
% p    = excitation vector/file
% dt   = time step in excitation file
% m    = mass of SDF system
% wn2  = square of wn
% k    = stiffness of SDF system
% c    = damping of SDF system
% N    = number of data points in excitation file
% kHat = effective stiffness in algorithm
% a    = one of the constants for effective force in algorith
% b    = one of the constants for effective force in algorith
% a0   = initial acceleration for use in determining u(-1)
% u_1  = displacement immediately before u0 (ie u(-1))
% u    = relative displacement history
% v    = relative velocity history
%
% Note: Units are specified by excitation file p
%% ------------------------------------------------------------------------
function [u,v] = CentralDifference(flag,wn,xi,u0,v0,p,dt)
%% Computation of constants for procedure
m = 0.2533;
if flag == 1
    p = -m*p;
end
wn2 = wn^2;
k = wn2*m;
c = 2*xi*m*wn;
N = length(p);
kHat = m/(dt)^2+c/(2*dt);
a = m/(dt)^2-c/(2*dt);
b = k-(2*m)/(dt)^2;

%% Initialization of response histories
a0 = (p(1)-c*v0-k*u0)/m;
u_1 = u0-dt*v0+0.5*(dt)^2*a0;
u = zeros(1,N);     v = zeros(1,N);
u(1) = u0;          v(1) = v0;
u(2) = (p(1)-a*u_1-b*u0)/kHat;

% Central difference method
for i=3:N
    pHat = p(i-1)-a*u(i-2)-b*u(i-1);
    u(i) = pHat/kHat;
    v(i-1) = (u(i)-u(i-2))/(2*dt);
end

% Obtain last data point for velocity history
v(N) = ((p(N)-a*u(N-1)-b*u(N))/kHat-u(N-1))/(2*dt);
end

%% Example for checking method
% % Excitation input is half sine pulse
% % Theoretical u = exp(-zetawnt)(Acoswnt+Bsinwnt)+Csinwt+Dcoswt
% pmax = 10;
% w = pi/0.6;
% wd = wn*sqrt(1-xi^2);
% C = pmax/k*(1-(w/wn)^2)/((1-(w/wn)^2)^2+(2*xi*w/wn)^2);
% D = pmax/k*(-2*xi*w/wn)/((1-(w/wn)^2)^2+(2*xi*w/wn)^2);
% A = u0-D;
% B = (v0+xi*wn*A-C*w)/wd;
% [u,v] = CentralDifference(2*pi,0.05,0,0,p,0.1)