%% ------------------------------------------------------------------------
% Compute values for stress strain relations for confined and unconfined
% concrete for columns of Skew Bridge
% 
% Written by: Neal Simon Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010
%% ------------------------------------------------------------------------
clear all; clc;

%% --------------SECTION PROPERTIES INPUT----------------------------------
fc = 1.3;           %ksi
fyt = 24;           %ksi
Es = 29000000;      %psi
s = 3.5;            %spiral pitch in inches
Abar = 0.20;        %in^2 for number 4 (US system) spirals
Dgross = 5*12;      %gross diameter of section in inches
ccover = 3.125;     %cover in inches

%% ---------------ANALYSIS-------------------------------------------------
E = 57000*sqrt(fc*1000);    %concrete modulus in psi
D = Dgross-2*ccover;        %core diameter

% Unconfined concrete
ec0 = 0.002;        %strain at max stress = f'c
fc = 0.85*fc;       %account for in-situ strength
ecu = 0.005;        %strain at failure
fcu = fc*0.20;      %stress at failure(approx)

% Confined concrete
ps = (4*Abar)/(D*s);        %spiral reinforcement ratio
ke = 1-s/D;                 %confinement effectiveness
fs = Es*(0.0025+0.21*((ke*ps)/(fc*1000))^(1/3));    %spiral stress cap in psi
if(fs>(fyt*1000))
    fs = fyt;       %ksi
end
fe = ke*ps*fs/2;    %effective confinement stress in ksi

% % Use Mander model graph to get f'cc
% disp(fe/fc)
% fcc = 1.3*fc;       %ksi

% From Richart et al (1928)
fcc = fc+4.1*fe;
ecc0 = ec0*(1+5*(fcc/fc-1));
% Recommended from Prof Moehle in CE244 reader: Fig 4.4.1
eccu = 0.004+0.25*fe/fc;

% Using Mander model, get stress at failure assuming hoop fracture
x = eccu/ecc0;
r = E/(E-(fcc*1000)/ecc0);
fccu = fcc*(x*r)/(r-1+x^r);

%% ---------------OUTPUT---------------------------------------------------
% Display values for material input into OpenSEES
disp(['fc is: ' num2str(fc) ' ksi'])
disp(['ec0 is: ' num2str(ec0)])
disp(['fcu is: ' num2str(fcu) ' ksi'])
disp(['ecu is: ' num2str(ecu)])
disp(['fcc is: ' num2str(fcc) ' ksi'])
disp(['ecc0 is: ' num2str(ecc0)])
disp(['fccu is: ' num2str(fccu) ' ksi'])
disp(['eccu is: ' num2str(eccu)])
disp(['fy is: ' num2str(fyt) ' ksi'])


