% Linear Interpolation of Excitation Numerical SDF Solution Method
% Function to calculate displacement & velocity response histories
%
% Written by: N.Kwong
% Date Modified: 25 Nov 2010
%% ----------------------DEFINITIONS---------------------------------------
% flag = indicator for ground motion (1 = yes)
% wn   = natural circular frequency in rad/sec^2
% xi   = damping ratio
% u0   = initial displacement
% v0   = initial velocity
% p    = excitation vector/file
% dt   = time step in excitation file
% m    = mass of SDF system
% wn2  = square of wn
% k    = stiffness of SDF system
% N    = number of data points in excitation file
% u    = relative displacement history
% v    = relative velocity history
%
% Note: Units are specified by excitation file p
%% ------------------------------------------------------------------------
function [u,v] = LinearInterpolation(flag,wn,xi,u0,v0,p,dt,k)
%% Computation of constants for procedure
wn2 = wn^2;
m = k/wn2;
if flag == 1
    p = -m*p;
end
wd = wn*sqrt(1-xi^2);
N = length(p);
A = exp(-xi*wn*dt)*((xi/sqrt(1-xi^2))*sin(wd*dt)+cos(wd*dt));
B = exp(-xi*wn*dt)*sin(wd*dt)/wd;
C = 1/k*(2*xi/(wn*dt)+exp(-xi*wn*dt)*(((1-2*xi^2)/(wd*dt)-xi/sqrt(1-xi^2))*sin(wd*dt)-(1+2*xi/(wn*dt))*cos(wd*dt)));
D = 1/k*(1-2*xi/(wn*dt)+exp(-xi*wn*dt)*((2*xi^2-1)/(wd*dt)*sin(wd*dt)+2*xi/(wn*dt)*cos(wd*dt)));
Ap = -exp(-xi*wn*dt)*(wn/sqrt(1-xi^2)*sin(wd*dt));
Bp = exp(-xi*wn*dt)*(cos(wd*dt)-(xi/sqrt(1-xi^2))*sin(wd*dt));
Cp = 1/k*(-1/dt+exp(-xi*wn*dt)*((wn/sqrt(1-xi^2)+xi/(dt*sqrt(1-xi^2)))*sin(wd*dt)+cos(wd*dt)/dt));
Dp = 1/(k*dt)*(1-exp(-xi*wn*dt)*(xi/sqrt(1-xi^2)*sin(wd*dt)+cos(wd*dt)));

%% Initialization of response histories
u = zeros(1,N);     v = zeros(1,N);
u(1) = u0;          v(1) = v0;

% Superposition of Exact Solutions as Recurrence Formulas
for i=1:(N-1)
    u(i+1) = A*u(i)+B*v(i)+C*p(i)+D*p(i+1);
    v(i+1) = Ap*u(i)+Bp*v(i)+Cp*p(i)+Dp*p(i+1);
end

end
