%% ------------------------------------------------------------------------
% Modal Quantities Calculator
%
% Summary: Current directory should contain massList.txt file for mass
% matrix and Mode_#x(y).out files for mode shapes. These are used to
% compute and display modal contribution and participation factors.
%
% Written by: Neal Simon Kwong (nealsimonkwong@berkeley.edu)
% Date modified: Nov 2010
%% ----------------------DEFINITIONS---------------------------------------
% modalDirectory    = specifies path to locate modal output 
% numModes          = max number of modes script will deal with
% cntrlNode         = node # for control node in pushover analyses
% mVec              = vector of mass entries for all nodes in one direction
% mMatrix           = diagonal matrix of masses for all nodes
% iota              = influence vector used to establish quasi-static
%                     displacements
% mTotal            = total mass of model
% Mn                = generalized mass for nth natural mode
% Ln                = numerator term for modal participation factor
% Rn                = modal participation factor
% Mneff             = effective modal mass
% phiMaster         = the modal displacement at control node
% rnbar             = modal contribution factor

%% User Input
clear all;  clc;

modalDirectory = 'J:\MPS\Skew Bridge\OpenSees_Skw\EigOutput';
cd(modalDirectory)

numModes = 12;
cntrlNode = 39;

%% Modal Computation
% Obtain mass matrix (which is same for x and y directions)
mVec = load('massList.txt');
mMatrix = diag(mVec,0);
% Create influence vector
iota = ones(length(mVec),1);
mTotal = mVec*ones(length(mVec),1);
% Check total weight against OpenSEES output of total weight
disp(strcat('Total weight of structure is: ',num2str(mTotal*32.2),' kips'));

for modeNum=1:numModes
    % Extract mode vectors
    % Note: Modez is not extracted because no mass is assigned in that
    % direction since excitation is only x and y
    modex = (load(['Mode_' num2str(modeNum) 'x.out']))';
    modey = (load(['Mode_' num2str(modeNum) 'y.out']))';

    Mn(modeNum,modeNum) = modex'*mMatrix*modex+modey'*mMatrix*modey;

    Ln(1,modeNum) = modex'*mMatrix*iota;
    Rn(1,modeNum) = Ln(1,modeNum)/Mn(modeNum,modeNum);
    Mneff(1,modeNum) = Ln(1,modeNum)*Ln(1,modeNum)/Mn(modeNum,modeNum);
    phiMaster(1,modeNum) = modex(cntrlNode);
    
    Ln(2,modeNum) = modey'*mMatrix*iota;
    Rn(2,modeNum) = Ln(2,modeNum)/Mn(modeNum,modeNum);
    Mneff(2,modeNum) = Ln(2,modeNum)*Ln(2,modeNum)/Mn(modeNum,modeNum);
    phiMaster(2,modeNum) = modey(cntrlNode);

    disp(['Static contribution from x-comp of mode ' num2str(modeNum) ' is: ' num2str(Mneff(1,modeNum)/mTotal*100) ' percent'])
    disp(['Modal participation from x-comp of mode ' num2str(modeNum) ' is: ' num2str(Rn(1,modeNum))])
    disp(['Static contribution from y-comp of mode ' num2str(modeNum) ' is: ' num2str(Mneff(2,modeNum)/mTotal*100) ' percent'])
    disp(['Modal participation from y-comp of mode ' num2str(modeNum) ' is: ' num2str(Rn(2,modeNum))])
end

%% Excel output
% For Excel file ModalContributions.xls
rnbar = (100/mTotal)*Mneff;
output1 = [rnbar(2,:)' rnbar(1,:)'];
output2 = [Rn(2,:)' Rn(1,:)'];

open output1
open output2