%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Story Drift and Displacement Plotting Routine (Transverse Direction)
%
% Summary: For the input, these need to be done first:
% - Create Excel file ESDOF-SkewBridge.xls
% - Manually create SaSd_Skw.txt file containing SD in first column and SA
%   in second column
% 
% 1) This file plots SDF pushover data from SaSd_Skw.txt file and uses 
% values from the Excel file to plot idealized versions.
%                   
% Written by E.Kalkan
% Modified by N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified : Nov 2010 

%% ----------------------DEFINITIONS---------------------------------------
% g         = gravitational acceleration (in/sec2)
% convF     = used to convert inches (from Excel) to cm for plots
% Ti        = fundamental period in current direction
% wnsqr_i   = used for plotting/showing initial slope of curve
% Dny       = yield displacement of equivalent SDF system (used to plot
%             junction of idealized curve)
% Vbny      = yield acceleration of equivalent SDF system (used to plot
%             junction of idealized curve)
% Dn        = final displacement of ESDOF system (used to plot endpt of
%             idealized curve)
% Vbn       = final acceleration of ESDOF system (used to plot endpt of
%             idealized curve)
% scale     = used to stretch or shrink initial tangent line in plot
% Dni       = used to draw the initial tangent line in plot
% Vbni      = used to draw the initial tangent line in plot
% x#        = used to position the annotation in plot
% y#        = used to position the annotation in plot
% SaSd      = SDF pushover data in directory for direction considered
% xmax      = used to adjust the x-axis of plot
% ymax      = used to adjust the y-axis of plot

%% User Input~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
clear all; clc; close all;
g = 386.4;
convF = 2.54;

Ti = 0.51;
wnsqr_i = ((2*pi)/Ti)^2;

% Yield data point of idealized curve
Dny = 1.3*convF;     % in cm
Vbny = 190/g;       % in units of g
% Post yield data point of idealized curve
Dn = 8*convF;       % in cm
Vbn = 860/g;        % in units of g
% Data point for initial tangent line
scale = 5;
Dni = Dny*scale;
Vbni = (Dny/convF*wnsqr_i/g)*scale;

% Annotation adjustments
tit1 = 'T_i = 0.51 s';
x1 = 1; y1 = 1.0;
tit2 = 'T_e_f_f = 0.52 s';
x2 = 3; y2 = 0.2;
tit3 = '\alpha = 0.68';
x3 = 15; y3 = 1.5;
tit4 = 'Transverse Dir.';
x4 = 10; y4 = 0.5;

% Input path
SaSd = load ('J:\MPS\Skew Bridge\Pushover\Pushover_Trans\ModalPushover_2\SaSd_Skw.txt');

% Axis adjustments
xmax = 20;
ymax = 2.5;

% For output files
fpath = 'J:\MPS\Skew Bridge\Figures\';
fname = 'Fig_16_SaSdFit';
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

%% Plot equivalent SDF pushover curves-------------------------------------
figure(1); orient tall; clf; 
set(gcf,'position',[300 283 300 300]);
set(gca,'TickLength',[.0025 .0025]);
plot(SaSd(:,1)*convF,SaSd(:,2)/g,'k-','LineWidth',2.0);
axis([0 xmax 0 ymax]); axis square;
xlabel('D_1 (cm)','FontSize',[9],'FontWeight','bold','FontAngle','italic');
%set(gca,'YTickLabel',{'0','','0.1','','0.2','','0.3'},'fontsize',8);
ylabel('FS_1 / L_1 (g)','FontSize',[9],'FontAngle','italic','FontWeight','bold');
X1 = [0 Dny]; Y1 = [0 Vbny]; line(X1,Y1,'LineStyle','--','LineWidth',2.0,'Color','b');
X2 = [Dny Dn]; Y2 = [Vbny Vbn]; line(X2,Y2,'LineStyle','--','LineWidth',2.0,'Color','b');
X3 = [0 Dni]; Y3 = [0 Vbni]; line(X3,Y3,'LineStyle','--','LineWidth',2.0,'Color',[0.5 0.5 0.5]);

% Annotate plot
text('pos',[x1 y1],'str',tit1,'FontSize',[9],'FontWeight','bold');
text('pos',[x2 y2],'str',tit2,'FontSize',[9],'FontWeight','bold');
text('pos',[x3 y3],'str',tit3,'FontSize',[9],'FontWeight','bold');
text('pos',[x4 y4],'str',tit4,'FontSize',[9],'FontWeight','bold');

% savefile(fpath,fname);