% This file is used in response_TCL_NGA.m
% Function to calculate spectral displacement, velocity, & acceleration
% Utilizes a solution algorithm to obtain relative displacment history
%
% Written by: E.Kalkan
% Modified by: N.Kwong
% Date Modified: 09 Nov 2010
%% ----------------------DEFINITIONS---------------------------------------
% sPeriod          = vector containing periods of interest for spectrum
% xi               = damping ratio
% dt               = time step in ground acceleration file         
% gacc             = ground acceleration file
% N                = number of data points 
% displ_max        = Spectral relative displacement (cm)
% veloc_max        = Spectral relative velocity (cm/sec)
% absacc_max       = Spectral absolute acceleration (cm/sec)
% foverm_max       = Spectral value of lateral resisting force over mass
%                    (cm/sec)
% pseudo_acc_max   = Pseudo spectral acceleration (cm/sec)
% pseudo_veloc_max = Pseudo spectral velocity (cm/sec)
% omegan           = natural circular frequency for SDF system
% foverm           = Lateral resisting force over mass (cm/sec)
% absacc           = Absolute acceleration from equilibrium (cm/sec)
%
% Note: Units are specified by gacc file (not necessarily cm)

%% ------------------------------------------------------------------------
function [pseudo_acc_max,pseudo_veloc_max,displ_max] = calcSpectrum(sPeriod,xi,dt,gacc,N)
%% Initialization
displ_max = zeros(1,length(sPeriod));
veloc_max = zeros(1,length(sPeriod));
absacc_max = zeros(1,length(sPeriod));
foverm_max = zeros(1,length(sPeriod));
pseudo_acc_max = zeros(1,length(sPeriod));
pseudo_veloc_max = zeros(1,length(sPeriod));
%% Determine spectral values
for i = 1:length(sPeriod);
    omegan = 2*pi/sPeriod(i);
    % Matrix solution algorithm
    [displ,veloc] = solveLESDF(omegan,xi,dt,gacc);
%     % Newmark's Linear solution algorithm
%     [displ,veloc] = NewMarkLinear(xi,omegan,0,0,gacc,dt);
%     % Linear interpolate excitation for Central difference method
%     while (dt/sPeriod(i) >= (1/pi))
%         dt = dt/2.0;
%         temp = zeros(1,2*length(gacc)-1);
%         temp(1) = gacc(1);
%         for j=2:length(gacc)
%             temp(2*j-1) = gacc(j);
%             temp(2*j-2) = (gacc(j)+gacc(j-1))/2;
%         end
%         gacc = temp;
%     end
%     % Central Difference solution algorithm
%     [displ,veloc] = CentralDifference(1,omegan,xi,0,0,gacc,dt);
%     % Superposition of Exact Solution Approach
%     [displ,veloc] = LinearInterpolation(1,omegan,xi,0,0,gacc,dt,1);

    foverm = omegan^2*displ;                % Lateral resisting force over mass (cm/sec)
    absacc = -2*xi*omegan*veloc-foverm;     % Absolute acceleration from equilibrium (cm/sec)

    % Extract spectral values
    displ_max(i) = max(abs(displ));               % Spectral relative displacement (cm)
    veloc_max(i) = max(abs(veloc));               % Spectral relative velocity (cm/sec)
    absacc_max(i) = max(abs(absacc));             % Spectral absolute acceleration (cm/sec)

    foverm_max(i) = max(abs(foverm));             % Spectral value of lateral resisting force over mass (cm/sec)
    pseudo_acc_max(i) = displ_max(i)*omegan^2;    % Pseudo spectral acceleration (cm/sec)
    pseudo_veloc_max(i) = displ_max(i)*omegan;    % Pseudo spectral velocity (cm/sec)

end
end