%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% M-file to perform spectral seismic analysis of linear SDOF oscillator.
%
% Summary: Must run response_TCL_NGA.m first to have .PSA and .SD spectral
% data ready in Spectra folder. Extracts data from all GMs and computes
% median spectrum (geometric mean). Writes the data for median spectrum in
% target_acc.txt file and plots all relevant spectra. 
% Current directory should contain Spectra folder.
%
% Written by E.Kalkan
% Modified by Neal Simon Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ----------------------DEFINITIONS---------------------------------------
% nGM             = number of ground motion records (one horiz. component)
% SF              = scale factor for individual records
% convF_AT2       = conversion factor to change units btw .AT2 and .TCL files
% SpecFolder      = name of folder that contains spectral data                    
%                   options: 'SpectraX', 'SpectraY'
% fpath           = file path to place saved figures 
% fname           = name for figures to be saved
% at2List         = stores list containing names for all .AT2 records
% filename        = name of .AT2 file read directly from at2List
% filename_c      = name of GM file without file extensions
% filename_a      = name of GM spectral acceleration file
% filename_d      = name of GM spectral displacement file
% fid1            = file identifier for spectral acceleration for GM
% fid2            = file identifier for spectral displacement for GM
% fid3            = file identifier for writing target Sa for GM
% fid4            = file identifier for writing target Sd for GM
% acc             = modified spectral acceleration (Sa) for GM
% disp            = modified spectral displacement (Sd) for GM
% sPeriod         = vector of periods for computing spectrum (T)
% y               = matrix with Sa for ith GM in ith column 
% x               = matrix with Sd for ith GM in ith column 
% medAccSpectra   = median Sa from suite of records
% meanAccSpectra  = average Sa from suite of records
% medDispSpectra  = median Sd from suite of records
% meanDispSpectra = average Sd from suite of records
% target_acc      = same as medAccSpectra
% target          = matrix containing T and median Sa for writing
% target_disp     = same as medDispSpectra
% targetD         = matrix containing T and median Sd for writing

%% Inputs/Initialization---------------------------------------------------
clear; close all;
% REMINDER: Current directory should contain 'input.txt' file which lists
% all the records that have corresponding spectral data obtained from
% response_TCL_NGA.m file
nGM = 21; 
SF  = 1.0; %(For individual records)
convF_AT2 = 981;

% Directory/folder names appropriate for GM component
SpecFolder = 'SpectraX';
fpath = 'H:\Skew Bridge\Figures\';
fname = 'Fig_2_Median_SpectraX';

%% Spectral Data Extraction from Appropriate Folder------------------------
% Summary: Extract spectral values from all records into 'y' and 'x'
% Methodology:
% Using fgets, all records are cycled through on list
% filename_c is version of filename without extensions
% The paths and names for the spectral data are then identified
% After bypassing first 3 lines, spectral values are extracted from files

at2List = fopen('input.txt','r');
for i = 1:nGM;
    filename = fgets(at2List);
    % -6 makes it such that name returned is free of extensions
    filename_c = filename(1:length(filename)-6);
    fprintf('GM in process = %s\n',filename_c);
    filename_a = strcat('./',SpecFolder,'/',filename_c,'.PSA');
    filename_d = strcat('./',SpecFolder,'/',filename_c,'.SD');

    [fid1,message] = fopen(filename_a,'r');   
    [fid2,message] = fopen(filename_d,'r');   

    % READ TEXT LINES to bypass heading and get to data 
    for k = 1:3;
        line = fgets(fid1);
        line = fgets(fid2);
    end
    acc = fscanf(fid1,'%15e %15e ',192)*SF;
    disp = fscanf(fid2,'%15e %15e ',192)*SF;
    cnt = 0;
    for j = 2:2:192;
        cnt = cnt+1;
        sPeriod(cnt) = acc(j-1);
        y(cnt,i) = acc(j)/convF_AT2;         % Transform from cm/sec2 to g
        x(cnt,i) = disp(j);
    end
end
%% Obtain median and mean spectra------------------------------------------
medAccSpectra = moving_average(geomean(y'),1);
medAccSpectra = medAccSpectra';
meanAccSpectra = mean(y,2);

medDispSpectra = geomean(x');
medDispSpectra = medDispSpectra';
meanDispSpectra = mean(x,2);
fclose('all');

%% Write target spectral data to current directory------------------------
target_acc = medAccSpectra;
target = [sPeriod' target_acc];

fid3 = fopen('target_acc.txt','w');

for i = 1:length(target_acc);
    fprintf(fid3,'%5.3f %5.3f \n', target(i,:));
end

target_disp = medDispSpectra;
targetD = [sPeriod' target_disp];

fid4 = fopen('target_disp.txt','w');

for i = 1:length(target_disp);
    fprintf(fid4,'%5.3f %5.3f \n', targetD(i,:));
end
fclose('all');
output = [sPeriod' medAccSpectra medDispSpectra];
open output  

%% Plot Median Spectrum with Individual Spectra----------------------------
figure(1);orient tall; clf; axis square;
set(gcf,'position',[200 300 450 450]);
set(gca,'TickLength',[.02 .02]);

plot(sPeriod,medAccSpectra,'r--','LineWidth',2.5); hold;
plot(sPeriod,y,'Color',[0.5,0.5,0.5]);
plot(sPeriod,medAccSpectra,'r--','LineWidth',2.5);
xlabel('Period (s), Tn','FontSize',[12],'FontWeight','bold');
ylabel('Pseudo Acceleration (g)','FontSize',[12],'FontWeight','bold');
axis([0 5 0 2.5]);

%h_legend=legend('Design Spectrum','Median Spectrum','ith GM  Spectrum');
h_legend = legend('Median','ith GM');
set(h_legend,'FontSize',13);
legend ('boxoff');
    
% savefile(fpath,fname);   
