%% Script to obtain Scale Factors for MPS-Exact method
% (Transverse Direction)
%
% Assumes the following have been done already:
% 1) Run 'response_TCL_NGA.m' file to create 'GMs' folder for placement
% of scale factor list (.txt and .mat files below)
%
% Summary: 
% 1) Creates input files under 'Inspec' folder for use with OpenSEES
% 2) Using OpenSEES, the NLRHA is performed on ESDOF system iteratively
% until scale factor is obtained for each record.
% 3) Summarizes all scale factors into .txt and .mat file and places these
% under 'GMs' folder for use with OpenSEES MDF NLRHA.
%
% Written by E.Kalkan
% Modified by Neal Simon Kwong (nealsimonkwong@berkeley.edu)
% Date Modified Dec 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% User Input
clear all; close all; 
SFinit = 1.0;  % CAREFULL !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
if SFinit > 1.0;
    fprintf('CAREFULL !!!! GROUND MOTIONS ARE UPSCALED BEFORE STARTING \n');
end

convF = 386.4;  % Convert from units of g to desired acceleration units

nGM = input('Number of ground motions in set: ', 's');   
nGM = str2num(nGM);

GMset = input('Obtain Scale Factors for which Set Number? (1,2,3): ', 's');

%% -------------Y-Dir (Transverse) INPUT----------------------------------
% Target spectral displacement in inches; should be same units as fy;
% obtain from pushover spreadsheet or PlotSaSdFit_Skw script
tgt = 2.84;             
Tn = 0.52;              % ESDOF fund period (sec)
fy = 190;               % ESDOF acceleration (Fs1/L1) in in/sec
b = 0.68;               % Post-yield hardening ratio
xi = 0.05;              % Damping ratio
GmFolder_Op = 'GMs';

% Specifies location of GM accelerations (.at2 files)
fpath_AT2 = strcat('H:\MPS\Skew Bridge\NLRHA\Sets\Set-',GMset,'\GM-Ycomp');

%% Create files to perform SDF NLRHA on OpenSEES & get Scale Factors
% Compute other material properties to be placed in .tcl file
omegan = 2*pi/Tn;       % Natural frequency (rad/sec)
E = omegan^2;
uy = fy/E;

% Change to directory containing .at2 acceleration files
cd(fpath_AT2);

dos(' dir *.AT2 /b/o >input.txt');
fid1 = fopen('input.txt','r');
warning off

% Display target displacement and draw border for output screen
fprintf('Target Displacement (inch) = %3.2f\n',tgt);
fprintf('-----------------------------------------------------\n');

% Prepare to record the scale factors at convergence
fp = fopen(strcat('..\',GmFolder_Op,'\Scale_Factors.txt'),'w');

for GM=1:nGM;
    clear output gacc tspan td dt
    
    % Find GM acceleration data from .at2 file
    fid = 0;
    while fid  < 1
        filename = fgets(fid1);
        filename_c = filename(1:length(filename)-2);
        fprintf('GM in process = %s\n',filename_c);
        [fid,message] = fopen(filename_c, 'r');
        if fid == -1;
            disp(message);
            break
        end
    end
    
    % Read heading lines (text) of .at2 file
    for i = 1:4;
        line = fgets(fid);
        if i == 4;
            npoint = line(2:7);
            dt = line(11:17);
        end
    end
    
    % Extract information from heading
    dt = str2num(dt);
    npoint = str2num(npoint);
    if npoint > 10000;
        npoint = 10000;
        fprintf('Ground Motion is Truncated to 10000 Data Points \n');
    end
    fprintf('Npoint = %5.0f; dt = %5.3f   \n',npoint,dt);
    
    % Extract GM acceleration data and perform unit conversion
    gacc = fscanf(fid,'%15e ',npoint);
    gacc = gacc*convF*SFinit;
    PGA(GM) = max(abs(gacc));               % In inch/sec if convF=386.4
    
    vel = cumsum(gacc)*dt;
    PGV(GM) = max(abs(vel));                % In inch/sec if convF=386.4
    
    disp = cumsum(vel)*dt;
    PGD(GM) = max(abs(disp));               % In inch if convF=386.4
    
    N = length(gacc);
    td = (N-1)*dt;                          % Duration of ground motion
    tspan = (0:dt:td);                      % Time vector (sec)
    
    % Create TCL version of GM acc for use with OpenSEES test.tcl file
    fpath = '.\InSpec\';
    GMname = strcat('M_',num2str(GM),'.tcl');
    fname = strcat(fpath,GMname);
    fid2 = fopen (fname,'w');
    fprintf (fid2,'%5.4f\n',gacc); fclose(fid2);
    
    % Create summary info for GM for use with OpenSEES test.tcl file
    fp1=fopen('.\InSpec\GMotion.tcl','w');
    fprintf(fp1,' set GM %5.0f',GM);
    fprintf(fp1,'\n set outFile %s',GMname);
    fprintf(fp1,'\n set Nsteps %5.0f',length(gacc));
    fprintf(fp1,'\n set dt %5.3f',dt); fclose(fp1);
    
    % Create material input for SDF system in OpenSEES
    fp1=fopen('.\InSpec\matInput.tcl','w');
    fprintf(fp1,'set fy %5.3f',fy);
    fprintf(fp1,'\n set E %5.3f',E);
    fprintf(fp1,'\n set b %5.3f',b);
    fprintf(fp1,'\n set epsy %5.3f',uy);
    fprintf(fp1,'\n set damp %5.3f',xi);
    fclose(fp1);
    
    % Call SDF NLRHA solver and iteration routine to obtain scale factors
    cd InSpec;
    [Scale_Factor displ veloc foverm] = SDOF_OP(tgt,uy,gacc,GM,omegan,xi,tspan,td,Tn,dt);
    cd ..
    Scales(GM) = Scale_Factor
    fprintf(fp,'%5.3f\n',Scales(GM));
end

ScaleFileName = strcat('../',GmFolder_Op,'/Scale_Factors.mat');
save(ScaleFileName,'Scales')
fclose('all'); 

