%% Calculation of "Exact" Target Deformation for MPS-Exact Method
% (Transverse Direction)
%
% Assumes the following are in current directory:
% 1) All GM acceleration time histories (.at2 files )
% 2) InSpecReg folder with the following items:
%   - OpenSEES.exe
%   - test.tcl
%   - RotSpring2D.tcl
%   - material.tcl
% 
% Summary: 
% 1) Extracts GM acceleration from .at2 files and converts to .tcl files
% 2) Creates associated Gmotion.tcl file in 'InSpecReg' folder
% 3) Invokes OpenSEES to perform NLRHA on SDF system for suite of records
% 4) Extracts OpenSEES displacement histories and obtains target peak
% inelastic deformation
% 
% Written by E.Kalkan
% Modified by Neal Simon Kwong (nealsimonkwong@berkeley.edu)
% Date Modified Dec 2010

%% User Input
clear all; close all;

nGM = input('Number of ground motions: ', 's');   
nGM = str2num(nGM);

% Artificial scaling factor to pre-scale GM's in .at2 files
convF = 386.4;
SF_manual = 1.0;

% Use Excel file or PlotSaSdFit_Skw script to enter ESDOF input
%-----------X-Direction---------------------------------------------------
Tn = 0.52;          % ESDOF fund period (sec)
fy = 190;            % ESDOF yield acceleration
b = 0.002;          % Post-yield hardening ratio
xi = 0.05;          % Damping ratio

% Specifies location of GM accelerations (.at2 files)
fpath_AT2 = 'H:\MPS\Skew Bridge\NLRHA\Sets_Exact\Target_Exact\GM-Ycomp';
%------------------------------------------------------------------------

%% Create necessary files and run OpenSees to analyze SDF system
% Change to directory containing .at2 files
cd(fpath_AT2);

dos(' dir *.AT2 /b/o >input.txt');
fid1 = fopen('input.txt','r');
warning off

% Draw border for output screen
fprintf('-----------------------------------------------------\n');

for GM=1:nGM;
    clear output gacc tspan td dt
        
    % Find GM acceleration data from .at2 file
    fid = 0;
    while fid  < 1
        filename = fgets(fid1);
        filename_c = filename(1:length(filename)-2);
        fprintf('GM in process = %s\n',filename_c);
        [fid,message] = fopen(filename_c, 'r');   
        if fid == -1;
                disp(message);
                break
        end
    end
    
    % Read heading lines (text) of .at2 file
    for i = 1:4;
        line = fgets(fid);
        if i == 4;
            npoint = line(2:7);
            dt = line(11:17);
        end      
    end
    
    % Extract information from heading
    dt = str2num(dt);
    npoint = str2num(npoint);
    if npoint > 10000;
        npoint = 10000;
        fprintf('Ground Motion is Truncated to 10000 Data Points \n');
    end
    fprintf('Npoint = %5.0f; dt = %5.2f   \n',npoint,dt);
    
    % Extract GM acceleration data and perform unit conversion
    gacc = fscanf(fid,'%15e ',npoint);
    gacc = gacc*convF*SF_manual;            % Transform from g to inch/sec
    PGA(GM) = max(abs(gacc));               % In inch/sec^2
    
    vel = cumsum(gacc)*dt;
    PGV(GM) = max(abs(vel));                % In inch/sec

    displacement = cumsum(vel)*dt;
    PGD(GM) = max(abs(displacement));               % In inch

    % Create TCL version of GM acc for use with OpenSEES test.tcl file
    fpath = '.\InSpecReg\';
    GMname = strcat('M_',num2str(GM),'.tcl');
    fname = strcat(fpath,GMname);
    fid2 = fopen (fname,'w');
    fprintf (fid2,'%5.4f\n',gacc); fclose(fid2);

    % Create summary info for GM for use with OpenSEES test.tcl file  
    fid3 = fopen('.\InSpecReg\GMotion.tcl','w');
    fprintf(fid3,' set GM %5.0f',GM);
    fprintf(fid3,'\n set outFile %s',GMname);
    fprintf(fid3,'\n set Nsteps %5.0f',length(gacc));
    fprintf(fid3,'\n set dt %5.3f',dt);
    fprintf(fid3,'\n set GMfatt %5.3f',1.0);
    fclose(fid3);
    
    fid4 = fopen('.\InSpecReg\matInput.tcl','w');
    fprintf(fid4,'set Tn %5.3f',Tn);
    fprintf(fid4,'\n set fy %5.3f',fy);
    fprintf(fid4,'\n set b %5.3f',b);
    fprintf(fid4,'\n set damp %5.3f',xi);
    fclose(fid4);
    
    % Analyze SDF system for each GM using OpenSEES test.tcl file
    cd .\InSpecReg
    dos('openSees test.tcl','-echo');
    cd ..
    
    % Some additional information about each GM record
    N = length(gacc);                       % Number of data points
    td = (N-1)*dt;                          % Duration of ground motion
    tspan = (0:dt:td);                      % Time vector (sec)
end

%% Determination of target deformation for MPS-Exact
% Obtaining target def. will be repeated in
% "Bar_PlotSDFdispComparison.m" script prior to making the plot;
% This value is used as input for "nonlinearSDOF_Op_Exact.m"

for GM=1:nGM;
    % IMPORTANT!!:  Clear variables every loop
    clear fid5 data displacement
    % Extract OpenSEES output into MATLAB
    fpath = '.\InSpecReg\';
    GMname = strcat('M_',num2str(GM),'-disp.out');
    fname = strcat(fpath,GMname);
    [fid5,message] = fopen(fname,'r');
    data = fscanf(fid5,'%15e %15e');
    cnt = 1;
    for j=2:2:length(data)
        displacement(cnt) = data(j);
        cnt = cnt+1;
    end
    % Extract peak displacement from each response history (SDFNLRHA) for
    % each ground motion and collect in vector
    Sdinel(GM,1) = max(abs(displacement));
end

% Obtain median peak inelastic displacement among all GM in suite
Dtgt_Exact = geomean(Sdinel);
fprintf('Target Disp Exact (inches) = %5.2f \n',Dtgt_Exact);
