%% Target Scaling Displacement Computation using Prof Chopra's CR eqn
% (Longitudinal Direction)
%
% Summary: For the input, these need to be done first:
% - Run the OpenSEES model to obtain NLFundPeriods.txt file
% - Run the ModalCalcs_Skw.m script to determine modal contributions
% - Perform pushover analyses and run globalpushSkw_Long.m and
%   globalpushSkw_Trans.m to convert OpenSEES pushover output for Excel
% - Use Excel to determine equivalent single degree of freedom (ESDOF)
%   properties for this file
% - Run both response_TCL_NGA.m and medianSpectra_Skw.m to obtain target
%   spectrum (which is the median spectrum)
% 
% 1) This file determines approximate target inelastic deformation
% 2) Before using chopraCR function, choose GM component as SDOF direction 
% 3) Resulting target displacement is used as "tgt" variable when running
%    nonlinearSDOF_Op_Skw.m or nonlinearSDOF_Op_Skw_Exact.m to get scale
%    factors
% 4) Writes summary to text file in user-specified directory (optional)
%
% Written by E.Kalkan
% Modified by Neal Simon Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010

%% ----------------------DEFINITIONS---------------------------------------
% g     = gravitational acceleration (in/sec2)
% convF = used to convert m to inches
% W     = total weight of the model (kips)
% fpath = specifies location to place text file summarizing results
% Tn    = fund period obtained from identifying the dominant modes in x and
%         y directions using ModalCalcs_Skw.m and NLFundPeriods.txt file
%         generated from running OpenSEES model
% tSd   = target spectral displacement obtained from target_disp.txt file
%         created using medianSpectra_Skw.m script
% tSa   = target spectral acceleration obtained from target_acc.txt file
%         created using medianSpectra_Skw.m script
% Tc    = period dividing the acceleration-sensitive and velocity-sensitive
%         regions in the tripartite spectrum (obtained from viewing
%         tripartite plot generated by response_TCL_NGA.m)
% fy    = yield acceleration (in/sec2) of equivalent single DOF system
%         corresponding to yield point of idealized pushover curve
%         (obtained from Excel file ESDOF-SkewBridge.xls; fy = Fsny/Ln)
% alpha = post-yield strain-hardening ratio from Excel file
% Ry    = yield strength reduction factor (Ry = fo/fy =
%         ((Mn*)*tSa)/((Mn*)*(Fsny/Ln)) = tSa/fy)
% CR    = inelastic deformation ratio used to estimate target inelastic
%         deformation in the equivalent SDOF system (obtained from
%         empirical equation as coded in ChopraCR function)

%% ---------------------INPUT FOR SPECIFIC STRUCTURE----------------------
g = 386.4;          
convF = 0.0254;
W = 3893;               % Weight in kips
fpath = 'H:\MPS\Skew Bridge\NLRHA\Benchmark\GM-Xcomp\';

%-----------X-Direction---------------------------------------------------
Tn      = 0.87;         % Period of 1st mode ESDOF (both x and y dir)
tSd     = 14.8288/100;  % in m
tSa     = 0.8273;       % in g
Tc      = 0.9;    
fy      = 52;           % Units of in/sec^2
alpha   = 0.002;        % It is assumed to be zero, in reality it is negative, CHECK IT.
%------------------------------------------------------------------------

%% Target computation
fprintf('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n');
fprintf('Med. Sa (g) = %5.2f \n',tSa);
fprintf('Med. Sd (m) = %5.2f \n',tSd);
fprintf('Med. Sd (in) = %5.2f \n',tSd/convF);

Ry = tSa*g/fy;    
if Ry < 1
    Ry = 1;
end

CR = chopraCR(Tn,Tc,Ry,alpha);

% Print to Screen
fprintf('R_Paper        = %5.2f \n',Ry);
fprintf('CR = %5.3f \n',CR);
fprintf('Scaling Disp. (Chopra) (in) = %5.2f \n',CR*tSd/convF);
fprintf('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n');

% Print to File
fname = strcat(fpath,'targetSpectralDisp.out');
fid = fopen(fname,'w');
fprintf(fid,'Med. Sa (g)    = %5.2f \n',tSa);
fprintf(fid,'Med. Sd (inch) = %5.2f \n',tSd);
fprintf(fid,'R (Fel/Fy)     = %5.2f \n',Ry);
fprintf(fid,'CR = %5.3f \n',CR);
fprintf(fid,'Scaling Disp. (Chopra) (in) = %5.2f \n',CR*tSd/convF);
fclose(fid);

