%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% NLRHA Drift Ratio on Pushover Curve Plotting Routine (Transverse Direction)
%                   
% Summary: This script extracts drift ratios from NLRHA and plots them on
% the structure's pushover curve to view the extent of inelasticity during
% NLRHA
% 
% Written by E. Kalkan
% Modified by: N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010

%% ----------------------DEFINITIONS---------------------------------------
% h             = height of the model (ie columns in bent)
% W             = total weight of structure in kips
% g             = gravitational acceleration (in/sec2)
% convF         = used to convert inches from pushover data to feet
% fpath_Push    = specifies location of pushover data
% fpath_NLRHA   = specifies location of NLRHA workspace file generated
%                 using post_process_Skw.m script
% fpath         = specifies location of saved figures
% fname         = specifies name of saved figures
% tit           = title of plot
% X,Yplacement  = used to adjust placement of text on plots
% push          = pushover data with first column as displacement and
%                 second column as base shear (see globalpushSkw_Trans.m)
% x,y           = size of RDR vector from NLRHA workspace file where x
%                 should be 1 and y should be total number of records
% roofD         = this is identical to RDR but with a different name
% medroofD      = median drift ratio among all records
% BShear        = vector of base shear values that correspond to roofD from
%                 all ground motions

%% User Input~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
clear all; clc; close all;

h = 26.8333;
W = 3893; 
g = 32.2;
convF = 1/12;

fpath_Push = 'J:\Skew Bridge\Pushover\Pushover_Trans\ModalPushover_2\pushover.txt';
fpath_NLRHA = 'J:\Skew Bridge\NLRHA\Benchmark\Skew_Unscaled\post_process.mat';
fpath = 'J:\Skew Bridge\Figures\';
fname = 'Fig_22_PushoverCurvesComp_PGA';

tit = 'Skew Bridge (Trans)';
% For placement of text in figures
Xplacement = 1.3;
Yplacement = 2.0;

%% Extract Pushover Data
File_Push = load(fpath_Push);
push(:,1) = File_Push(:,1)/h*convF;
push(:,2) = File_Push(:,2)/W;

%% Extract NLRHA Drift Ratios and Find Corresponding Base Shear Values
load(fpath_NLRHA);
[x y] = size(RDR);
roofD = RDR(x,:); 
medroofD = geomean(roofD);
for jj = 1:y;
    for kk = 1:length(push(:,1));
        if roofD(jj) == push(kk,1);
            BShear(jj) = push(kk,2);
        elseif roofD(jj)< push(kk,1) && roofD(jj)> push(kk-1,1);
            BShear(jj) = (push(kk,2)+push(kk-1,2))/2;
        end
    end
end

%% Plot Roof Drift Ratios on Pushover Curve
figure(1); orient tall; clf; 
set(gcf,'position',[300 283 300 300]);
set(gca,'TickLength',[.0025 .0025]);

plot(push(:,1),push(:,2),'k-','LineWidth',2.0); hold;
plot(roofD,BShear,'o','Linestyle','o','MarkerSize',6,...
        'MarkerEdgeColor','k','MarkerFaceColor','b'); 
plot([medroofD,medroofD], [0,1.5],'--r','LineWidth',2.0);
text('pos',[(medroofD-0.002)*Xplacement (max(BShear)/3)*Yplacement],'str','Median','FontSize',[9],'FontWeight','bold','Rotation',90);
set(gca,'Xtick',[0:0.005:0.02])
set(gca,'XTickLabel',{'0','0.5','1','1.5','2'},'fontsize',9);
axis([0 0.02 0 1.4 ]); axis square;
% text('pos',[0.007 0.54],'str',tit,'FontSize',[9],'FontWeight','bold');
% set(gca,'YTickLabel',{'0','','0.1','','0.2','','0.3','','0.4'},'fontsize',9);
ylabel('Base Shear / Weight','FontSize',[9],'FontWeight','bold'); 
xlabel('Deck Drift Ratio (%)','FontSize',[9],'FontWeight','bold'); 

% savefile(fpath,fname);  