%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% M-file for plotting pushover data from OpenSees and writing to text file
% for use with Excel spreadsheet (ESDOF-SkewBridge.xls)
%
% Summary: Longitudinal Direction
% Extracts pushover data from OpenSEES output
% Plots data and writes to text file for use with Excel
%
% Note: Longitudinal direction => "dof 1" in OpenSEES model
%
% Written by E.Kalkan
% Modified by N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ----------------------DEFINITIONS---------------------------------------
% R_output    = this specifies location and name of reaction output
% D_output    = this specifies location and name of displacement output
% txtConvFile = this specifies location and name of text file 
% rFile1      = file containing all reactions
% shear1      = vector of base shears in trans dir
% dFile1      = file containing all displacements
% disp1       = vector of control node displacements in trans dir
% wsqr        = "k/m" quantity throughout load hist.
% T           = for seeing how period roughly changes throughout load hist.
% drift       = displacements normalized by height
% VoverW      = base shears normalized by weight
% Fsn_Ln      = accelerations of equivalent sdof system (ESDOF)
% Dn          = displacements of equivalent sdof system (ESDOF)

%% User input
clear all; clc; close all;
R_output = 'J:\MPS\Skew Bridge\Pushover\Pushover_Long\ModalPushover_1\Reactions_Long.out';
D_output = 'J:\MPS\Skew Bridge\Pushover\Pushover_Long\ModalPushover_1\MasterNodeDisp_Long.out';
txtConvFile = 'J:\MPS\Skew Bridge\Pushover\Pushover_Long\ModalPushover_1\pushover.txt';

height = 26.8333;           % height of model in ft
weight = 3893;              % total weight model in kips
g = 32.2;                   % grav constant in ft/sec2
convF = 12;                 % optional conversion factor for use in Excel

%% Initialization
mass = weight/g;

%% OpenSEES Data Extraction
rFile1 = load(R_output);               % 1 corresponds to dof 1 in OS model (x dir)
shear1 = rFile1(:,1) + rFile1(:,4) + rFile1(:,7) + rFile1(:,10); % 4 nodes at bc

dFile1 = load(D_output);
disp1 = dFile1(:,2);

% Period check
wsqr = (-1/mass)*shear1./disp1;
for i=1:length(wsqr)
    T(i) = (2*pi)/sqrt(wsqr(i));
end

open T

%% Plot and Write to text
drift = disp1*(100/height);
VoverW = shear1*(-1/weight);

% Plot pushover curve
set(gca,'FontSize',14);
plot(drift,VoverW,'bo-','LineWidth',2.5);
grid on
xlabel('Deck DR, %');
ylabel('Base shear/Weight');

% Write results
pushover = [disp1*convF abs(shear1)]';     %Convert disp to inches for Excel file
fid = fopen (txtConvFile,'w');  
fprintf (fid,'%6.4f %6.4f \n',pushover);
fclose(fid);

%% Optional ESDOF Period estimate
optFlag = input('Check ESDOF period? (y/n): ', 's');  
if optFlag == 'y';
    disp('Use ModalCalcs.m and ESDOF-name.xls files to check conversion values!!');
    alfan = 0.98;     %Modal contribution factor
    Rn = 10.9;           %Modal participation factor
    phiCntrlNode = 0.09;   %Modal displacement at control node
    
    Fsn_Ln = -shear1/(alfan*weight/g);
    Dn = disp1/(Rn*phiCntrlNode);
    wnsqr_check = (Fsn_Ln(2)-Fsn_Ln(1))/(Dn(2)-Dn(1));
    Tcheck = (2*pi)/(sqrt(wnsqr_check));
    disp(['Initial ESDOF period is approximately ' num2str(Tcheck) ' sec']);
end
