%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% M-file for plotting pushover data from OpenSees and writing to text file
% for use with Excel spreadsheet (ESDOF-SkewBridge.xls)
%
% Summary: Transverse Direction
% Extracts pushover data from OpenSEES output
% Plots data and writes to text file for use with Excel
%
% Note: Transverse direction => "dof 2" in OpenSEES model
%
% Written by E.Kalkan
% Modified by N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ----------------------DEFINITIONS---------------------------------------
% R_output    = this specifies location and name of reaction output
% D_output    = this specifies location and name of displacement output
% txtConvFile = this specifies location and name of text file 
% rFile2      = file containing all reactions
% shear2      = vector of base shears in trans dir
% dFile2      = file containing all displacements
% disp2       = vector of control node displacements in trans dir
% wsqr        = "k/m" quantity throughout load hist.
% T           = for seeing how period roughly changes throughout load hist.
% drift       = displacements normalized by height
% VoverW      = base shears normalized by weight
% Fsn_Ln      = accelerations of equivalent sdof system (ESDOF)
% Dn          = displacements of equivalent sdof system (ESDOF)

%% User input
clear all; clc; close all;
R_output = 'J:\MPS\Skew Bridge\Pushover\Pushover_Trans\ModalPushover_2\Reactions_Trans.out';
D_output = 'J:\MPS\Skew Bridge\Pushover\Pushover_Trans\ModalPushover_2\MasterNodeDisp_Trans.out';
txtConvFile = 'J:\MPS\Skew Bridge\Pushover\Pushover_Trans\ModalPushover_2\pushover.txt';

height = 26.8333;           % height of model in ft
weight = 3893;              % total weight model in kips
g = 32.2;                   % grav constant in ft/sec2
convF = 12;                 % optional conversion factor for use in Excel

%% Initialization
mass = weight/g;

%% OpenSEES Data Extraction
rFile2 = load(R_output);               % 2 corresponds to dof 2 in os model (y dir)
shear2 = rFile2(:,2) + rFile2(:,5) + rFile2(:,8) + rFile2(:,11); % 4 nodes at bc

dFile2 = load(D_output);
disp2 = dFile2(:,3);

% Period check
wsqr = (-1/mass)*shear2./disp2;
for i=1:length(wsqr)
    T(i) = (2*pi)/sqrt(wsqr(i));
end

open T

%% Plot and Write to text
drift = disp2*(100/height);
VoverW = shear2*(-1/weight);

% Plot pushover curve
set(gca,'FontSize',14);
plot(drift,VoverW,'bo-','LineWidth',2.5);
grid on
xlabel('Deck DR, %');
ylabel('Base shear/Weight');

% Write results
pushover = [disp2*convF abs(shear2)]';     %Convert disp to inches for Excel file
fid = fopen (txtConvFile,'w');  
fprintf (fid,'%6.4f %6.4f \n',pushover);
fclose(fid);

%% Optional ESDOF Period estimate
optFlag = input('Check ESDOF period? (y/n): ', 's');  
if optFlag == 'y';
    disp('Use ModalCalcs.m and ESDOF-name.xls files to check conversion values!!');
    alfan = 0.68;     %Modal contribution factor
    Rn = 9.0;           %Modal participation factor
    phiCntrlNode = 0.07;   %Modal displacement at control node
    
    Fsn_Ln = -shear2/(alfan*weight/g);
    Dn = disp2/(Rn*phiCntrlNode);
    wnsqr_check = (Fsn_Ln(2)-Fsn_Ln(1))/(Dn(2)-Dn(1));
    Tcheck = (2*pi)/(sqrt(wnsqr_check));
    disp(['Initial ESDOF period is approximately ' num2str(Tcheck) ' sec']);
end
