%% ------------------------------------------------------------------------
% Post processing of NLRHA output from OpenSEES
%
% Summary: This script is to be applied when current MATLAB directory
% contains the "output" folder generated by OpenSEES model. The folder
% should contain several other folders corresponding to NLRHA output for
% several ground motions. This script extracts the OpenSEES NLRHA output
% and creates a MATLAB workspace file version (post_process.mat). Also,
% plots of drift ratios and col rotations vs. "ith" ground motion are
% generated.
%
% Copyright (c) 2004 by E. Kalkan, :-)
% Modified by: N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010

%% ----------------------DEFINITIONS---------------------------------------
% h                     = height of the model (ie columns in bent)
% numGM                 = number of ground motions that have NLRHA output
% nsucc                 = tracks the ground motions with successful NLRHA 
% GM                    = vector listing all 21 records
% dp                    = decision parameter indicating success of NLRHA
% FileNodalDisp_Trans   = file containing displacement output from NLRHA 
% NodalDisp_Trans       = displacement history in transverse direction
% NodalDisp_Trans_Max   = peak displacement in history
% FilePlasticRot        = file containing plastic rotation output from NLRHA           
% PlasticRot            = has several columns for various response histories
% PlasticRot_Trans_Max  = peak plastic rotation 
% RDR                   = peak roof drift ratio (ie peak displacement
%                         divided by height in transverse direction)

%% User Input
clear all; close all; clc;

h = 26.8333;
numGM = 7;

%% Initialization
nsucc = 0;
GM = 1:21;

%% Extract OpenSEES NLRHA output
for NM = 1:numGM;

    num = GM(NM);
    ch1 = num2str(num);
    
    % Check fail or success    
    fid = 0;
    filename = strcat('./output/M_',ch1,'.log');
    [fid,message] = fopen(filename, 'r');
    if fid == -1
        disp(message);
    end
    line = fgets(fid);
    dp = line(10:19); % Decision parameter created in OpenSEES model
    if(dp == 'Successful');
        fprintf('Ground motion in process = %5.0f  Status = %s\n',num,dp); 
        nsucc = nsucc+1;
        
        FileNodalDisp_Trans = strcat('./output/M_',ch1,'/NodalDisp_Trans.out');
        FileNodalDisp_Long = strcat('./output/M_',ch1,'/NodalDisp_Long.out');

        NodalDisp_Trans = load(FileNodalDisp_Trans);
        NodalDisp_Long = load(FileNodalDisp_Long);
        
        NodalDisp_Trans_Max(nsucc) = max(abs(NodalDisp_Trans(:,2)));
        NodalDisp_Long_Max(nsucc) = max(abs(NodalDisp_Long(:,2)));

        FilePlasticRot = strcat('./output/M_',ch1,'/PlasticRot.out');
        PlasticRot = load(FilePlasticRot);

        % Peak plastic rotations at element 81 (base of column)
        % Use -xml option in OpenSEES recorders to see which columns to use
        PlasticRot_Trans_Max(nsucc) = max(max(abs(PlasticRot(:,2:3))));
        PlasticRot_Long_Max(nsucc) = max(max(abs(PlasticRot(:,4:5))));
        
%         figure(nsucc);
%         subplot(3,1,1);
%            plot(NodalDisp_Trans(:,1),NodalDisp_Trans(:,2));
%            ylabel('Disp. Trans');
%         subplot(3,1,2);
%            plot(NodalDisp_Long(:,1),NodalDisp_Long(:,2));
%            ylabel('Disp. Long');
%         subplot(3,1,3);
%            plot(NodalDisp_Trans(:,1),PlasticRot(:,2));
%            ylabel('Plastic Rotation Trans');
    end
end

%% Plot peak responses due to ground motions
subplot(4,1,1);
    plot(NodalDisp_Trans_Max*100/h,'ro');
    ylabel('DR Trans(%)');
    title('Peak Responses');
subplot(4,1,2);
    plot(NodalDisp_Long_Max*100/h,'ro');
    ylabel('DR Long(%)');
subplot(4,1,3);
    plot(PlasticRot_Trans_Max,'ro');
    ylabel('Plastic Rot Trans');
subplot(4,1,4);
    plot(PlasticRot_Long_Max,'ro');
    ylabel('Plastic Rot Long');  
    
%% Save data for future use    
RDR = NodalDisp_Trans_Max/h;
RDR_Long = NodalDisp_Long_Max/h;
save post_process.mat    

