%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% M-file to perform spectral seismic analysis of linear SDOF oscillator.
%
% Summary: 
% Generates tripartite spectrum plot given number of GMs with .at2 files
% Extracts one comp acc data from .at2 files in current directory per GM
% Creates TCL version per GM
% Computes and plots (optional) spectrum per GM
% Stores spectral data in user defined folder/directory per GM
% Note: All is for a single component of ground motion
%
% Written by E.Kalkan
% Modified by N.Kwong (nealsimonkwong@berkeley.edu)
% Date Modified: Nov 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ----------------------DEFINITIONS---------------------------------------
% wd          = tracks initial working directory; used for manipulating
%               folders and files in other directories
% GmFolder_Op = name of folder contain TCL files used for OpenSees
% SpecFolder  = name of folder contain spectral data
% fpath_TCL   = specifies path for placement of TCL files
% fpath_Spec  = specifies path for placement of spectral data
% at2List     = stores list containing names for all .AT2 records
% nGM         = number of GM records (should be <= total in at2List)
% fid         = file identifier indicating current .AT2 file
% filename    = name of .AT2 file read directly from at2List
% filename_cleaned = name of .AT2 file without trailing spaces
% pFlag       = indicator for optional plotting of individual spectra
% SF_manual   = scale factor to modify .AT2 files as "pre-scaled" motions
% convF_AT2   = conversion factor to change units btw .AT2 and .TCL files
% convF_TCL   = conversion factor to change units btw .AT2 and .TCL files
% T           = list of pts of interest when plotting ind. spectra
% GM          = variable tracking current record
% readGMat2   = function to read .AT2 files and make GMinfo.mat file
% GMinfo.mat  = output from readGMat2 function (used inside createTCL) 
% PGA         = peak ground acceleration for all records (units specified
%               by convF_AT2
% PGV         = peak ground velocity for all records (units specified by
%               convF_AT2
% PGD         = peak ground displacement for all records (units specified
%               by convF_AT2
% createTCL   = function for .TCL versions of acc data for OpenSees
% spectraInput    = function to retrieve input for computing spectrum
% sPeriod         = vector of periods for computing spectrum
% spectrumCompute = function to compute spectrum with various algorithms
% PSA             = peak spectral acceleration for all records (g)
% PSV             = peak spectral velocity for all records (cm/sec)
% SD              = peak spectral displacement for all records (cm)
% createSpecFiles = function to store spectral data
% plotIndSpectrum = function to plot individual spectrum
% PSVmed          = median of PSV from all records
% PGAmed          = median of PGA from all records
% PGVmed          = median of PGV from all records
% PGDmed          = median of PGD from all records
% normPSVmed      = median of normPSV from all records
% tripart         = function to plot median and design spectra on 4way log

%% User Inputs-------------------------------------------------------------
clear all; clc; close all;  tic
% REMINDER: Current directory should contain all .at2 files
wd = cd;
GmFolder_Op = 'GMs2';
SpecFolder = 'SpectraX';
fpath_TCL = strcat('..\',GmFolder_Op,'\');
fpath_Spec = strcat('.\',SpecFolder,'\');
% fpath_Tripart = 'H:\Skew Bridge\Figures\';
% fname_Tripart = 'Fig_2_TripartMedianSpectraX';

% Artificially scale ground motions to drive structure into inelastic range
SF_manual = 1.0;
convF_AT2 = 981;
convF_TCL = 2.54;

% List of periods of interest when plotting individual spectra
T = [0.18, 0.34, 0.41];

%% Initialization----------------------------------------------------------
% Create a text file listing all names of .at2 files
dos(' dir *.AT2 /b/o >input.txt');
at2List = fopen('input.txt','r');
nGM = input('Number of ground motions: ', 's');
nGM = str2num(nGM);
pFlag = input('Plot Individual Spectrum (y/n): ', 's');

PGA = zeros(1,nGM);
PGV = zeros(1,nGM);
PGD = zeros(1,nGM);

[Ti,Tf,xi,g,sPeriod] = spectraInput;

PSA = zeros(nGM,length(sPeriod));
PSV = zeros(nGM,length(sPeriod));
SD = zeros(nGM,length(sPeriod));
normPSV = zeros(nGM,length(sPeriod));
%% Directory/folder organization-------------------------------------------
warning off
% Creates folders in locations (user-specified in fpath)
mkdir(SpecFolder)
cd ..
mkdir(GmFolder_Op)
cd(wd)

%% Extract data from AT2, Make TCL version, Compute & Plot spectrum--------
for GM=1:nGM;
    clear pseudo_veloc_max pseudo_acc_max displ_max
    fid=0;
    while fid  < 1
        filename = fgets(at2List);
        % The minus 2 is for the two spaces after GMname.at2
        % (ie full filename with .at2 extension will be retrieved)
        filename_cleaned = filename(1:length(filename)-2);
        fprintf('GM in process = %s\n',filename_cleaned);
        [fid,message] = fopen(filename_cleaned, 'r');
        if fid == -1;
            disp(message);
            break
        end
    end
    
    readGMat2(filename,fid,convF_AT2,SF_manual);
    load GMinfo.mat

    % Values for tripartite plot
    PGA(GM) = max(abs(gacc));                       % PGA in cm/sec^2
    PGV(GM) = max(abs(cumsum(gacc)*dt));            % PGV in cm/sec
    PGD(GM) = max(abs(cumsum(cumsum(gacc))*dt^2));  % PGD in cm/sec

    createTCL(convF_TCL,fpath_TCL);

    [pseudo_acc_max,pseudo_veloc_max,displ_max] = calcSpectrum(sPeriod,xi,dt,gacc,npoint);

    PSA(GM,:) = (1/convF_AT2)*pseudo_acc_max;       % PSA in g
    PSV(GM,:) = pseudo_veloc_max;                   % PSV in cm/sec
    SD(GM,:) = displ_max;                           % SD in cm
    normPSV(GM,:) = PSV(GM,:) / PGV(GM);

    createSpecFiles(fpath_Spec, filename_c,sPeriod,pseudo_acc_max,displ_max);

    if pFlag == 'y';
        plotIndSpectrum(sPeriod,PSA(GM,:),T,filename_c)
    end
    
end
fclose('all');
%% Create list for opensees------------------------------------------------
cd(fpath_TCL)
dos(' dir *.tcl /b/o >input.txt');
cd(wd)
%% Plot Median and Design Spectra on Tripartite----------------------------
% Default is take median of columns (ie all records with DIM = 1)
PSVmed = median(PSV);
PGAmed = median(PGA);
PGVmed = median(PGV);
PGDmed = median(PGD);
normPSVmed = median(normPSV);

tripart(nGM+1,PSVmed,PGAmed,PGVmed,PGDmed);
toc

% savefile(fpath_Tripart,fname_Tripart);
